Package: TBSignatureProfiler
Title: Profile RNA-Seq Data Using TB Pathway Signatures
Version: 1.24.0
Authors@R: c(
    person("Kiloni", "Quiles", , "kiloni.quiles@rutgers.edu", role = c("cre"), 
            comment = c(ORCID = "0000-0002-7521-5255")),
    person("Aubrey R.", "Odom", , "aodom@bu.edu", role = c("aut", "dtm"),
           comment = c(ORCID = "0000-0001-7113-7598")),
    person("David", "Jenkins", , "dfj@bu.edu", role = c("aut", "org"),
           comment = c(ORCID = "0000-0002-7451-4288")),
    person("Xutao", "Wang", , "xutaow@bu.edu", role = "aut"),
    person("Yue", "Zhao", , "yuezh@bu.edu", role = "ctb",
           comment = c(ORCID = "0000-0001-5257-5103")),
    person("Christian", "Love", , "clove@bu.edu", role = "ctb"),
    person("W. Evan", "Johnson", , "wej@bu.edu", role = "aut")
  )
Description: Gene signatures of TB progression, TB disease, and other TB
    disease states have been validated and published previously. This
    package aggregates known signatures and provides computational tools
    to enlist their usage on other datasets. The TBSignatureProfiler makes
    it easy to profile RNA-Seq data using these signatures and includes
    common signature profiling tools including ASSIGN, GSVA, and ssGSEA.
    Original models for some gene signatures are also available.  A shiny
    app provides some functionality alongside for detailed command line
    accessibility.
License: MIT + file LICENSE
URL: https://github.com/wejlab/TBSignatureProfiler,
        https://wejlab.github.io/TBSignatureProfiler-docs/
BugReports: https://github.com/wejlab/TBSignatureProfiler/issues
Depends: R (>= 4.4.0)
Imports: ASSIGN (>= 1.23.1), BiocParallel, ComplexHeatmap, DESeq2, DT,
        edgeR, gdata, ggplot2, glmnet, GSVA (>= 1.51.3), HGNChelper,
        magrittr, methods, pROC, RColorBrewer, reshape2, ROCit,
        S4Vectors, singscore, stats, SummarizedExperiment, tibble
Suggests: BiocStyle, caret, circlize, class, covr, dplyr, e1071,
        impute, knitr, lintr, MASS, plyr, randomForest, rmarkdown,
        shiny, spelling, sva, testthat
VignetteBuilder: knitr
biocViews: GeneExpression, DifferentialExpression
Encoding: UTF-8
Language: en-US
LazyData: TRUE
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.2
git_url: https://git.bioconductor.org/packages/TBSignatureProfiler
git_branch: RELEASE_3_23
git_last_commit: 4755e55
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 01:06:58 UTC; biocbuild
Author: Kiloni Quiles [cre] (ORCID: <https://orcid.org/0000-0002-7521-5255>),
  Aubrey R. Odom [aut, dtm] (ORCID:
    <https://orcid.org/0000-0001-7113-7598>),
  David Jenkins [aut, org] (ORCID:
    <https://orcid.org/0000-0002-7451-4288>),
  Xutao Wang [aut],
  Yue Zhao [ctb] (ORCID: <https://orcid.org/0000-0001-5257-5103>),
  Christian Love [ctb],
  W. Evan Johnson [aut]
Maintainer: Kiloni Quiles <kiloni.quiles@rutgers.edu>
