# Coverage Script
# Run tests and generate Code Coverage Report

# Look at a specific script ---------------------------------------------------
#test_for_me <- function(codefile, testfile) {
#  test_file(testfile)
#  res <- covr::file_coverage(codefile, testfile)
#  print(res)
#  covr::report(res)
#}

#test_for_me("R/evaluate.R", "tests/testthat/test-evaluate.R")
# Look at whole package -------------------------------------------------------
# Gets percent coverage for entire package, by script
#covr::package_coverage()
#
# Report with gui (probably the best here)
#covr::report()
